# sharething
[![PyPI version](https://badge.fury.io/py/sharething.svg)](https://badge.fury.io/py/sharething)
[![Build Status](https://travis-ci.org/etataurov/sharething.svg?branch=master)](https://travis-ci.org/etataurov/sharething)

Share extensions in multiple flask sub-applications
